# Getting Started

Included within this directory are a set of example Jupyter notebooks. These notebooks will cover the functionality contained in the client for creating and interacting with Albert jobs.

* [Tutorial 1](tutorial_1_bec_jobs.md)
* [Tutorial 2](tutorial_2_barrier_jobs.md)
* [Tutorial 3](tutorial_3_abstractions.md)
* [Tutorial 4](tutorial_4_experiments.md)
* [Tutorial 5](tutorial_5_optimization.md)

<link href="../main.css" rel="stylesheet" />
